# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.authenticated_session_user_agent import AuthenticatedSessionUserAgent

class TestAuthenticatedSessionUserAgent(unittest.TestCase):
    """AuthenticatedSessionUserAgent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthenticatedSessionUserAgent:
        """Test AuthenticatedSessionUserAgent
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthenticatedSessionUserAgent`
        """
        model = AuthenticatedSessionUserAgent()
        if include_optional:
            return AuthenticatedSessionUserAgent(
                device = authentik_client.models.authenticated_session_user_agent_device.AuthenticatedSession_user_agent_device(
                    brand = '', 
                    family = '', 
                    model = '', ),
                os = authentik_client.models.authenticated_session_user_agent_os.AuthenticatedSession_user_agent_os(
                    family = '', 
                    major = '', 
                    minor = '', 
                    patch = '', 
                    patch_minor = '', ),
                user_agent = authentik_client.models.authenticated_session_user_agent_user_agent.AuthenticatedSession_user_agent_user_agent(
                    family = '', 
                    major = '', 
                    minor = '', 
                    patch = '', ),
                string = ''
            )
        else:
            return AuthenticatedSessionUserAgent(
                device = authentik_client.models.authenticated_session_user_agent_device.AuthenticatedSession_user_agent_device(
                    brand = '', 
                    family = '', 
                    model = '', ),
                os = authentik_client.models.authenticated_session_user_agent_os.AuthenticatedSession_user_agent_os(
                    family = '', 
                    major = '', 
                    minor = '', 
                    patch = '', 
                    patch_minor = '', ),
                user_agent = authentik_client.models.authenticated_session_user_agent_user_agent.AuthenticatedSession_user_agent_user_agent(
                    family = '', 
                    major = '', 
                    minor = '', 
                    patch = '', ),
                string = '',
        )
        """

    def testAuthenticatedSessionUserAgent(self):
        """Test AuthenticatedSessionUserAgent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
